# rectvision
Flexibility to Computer Vision - Get the best out of your data

RectVision is an edge intelligence platform that leverages on data, pipeline ochestration and edge deployment of AI systems / models.

![image](img/rectvision.png)

Edge Deployment on:

* FPGAs - FPGA Modules
* TPUs 
* GPUs 
* Mobile Applications - Mobile App modules
* Drones - Drone modules

`[backend api](http://164.92.64.23/api/docs/#/)`

## Installation
Rectvision supports an installation of Python 3.6 and above. It is available on Windows, MacOS and Linux Systems.

### pip (Recommended)
To install the current `rectvision` you'll need at least Python 3.6.1. If you have an older version of Python, you will not be able to use `rectvision`.

```shell
$ pip install --upgrade rectvision
```

Alternatively, you may download the wheels from [PyPi](https://pypi.org/project/rectvision/#files)

## Getting Started
### Settings
### Data
### Processors
